@@ -68,7 +68,7 @@ inline  void   WelsUpdateSpatialIdxMap (sWelsEncCtx* pEncCtx, int32_t iPos, SPic
 
 /***************************************************************************
 *
-*	implement of the interface
+*   implement of the interface
 *
 ***************************************************************************/
 
@@ -122,9 +122,9 @@ int32_t CWelsPreProcess::WelsPreprocessReset (sWelsEncCtx* pCtx) {
 }
 
 int32_t CWelsPreProcess::AllocSpatialPictures (sWelsEncCtx* pCtx, SWelsSvcCodingParam* pParam) {
-  CMemoryAlign* pMa						= pCtx->pMemAlign;
-  const int32_t kiDlayerCount					= pParam->iSpatialLayerNum;
-  int32_t iDlayerIndex							= 0;
+  CMemoryAlign* pMa             = pCtx->pMemAlign;
+  const int32_t kiDlayerCount   = pParam->iSpatialLayerNum;
+  int32_t iDlayerIndex          = 0;
 
   // spatial pictures
   iDlayerIndex = 0;
@@ -155,7 +155,7 @@ int32_t CWelsPreProcess::AllocSpatialPictures (sWelsEncCtx* pCtx, SWelsSvcCoding
 }
 
 void CWelsPreProcess::FreeSpatialPictures (sWelsEncCtx* pCtx) {
-  CMemoryAlign* pMa	= pCtx->pMemAlign;
+  CMemoryAlign* pMa = pCtx->pMemAlign;
   int32_t j = 0;
   while (j < pCtx->pSvcParam->iSpatialLayerNum) {
     uint8_t i = 0;
@@ -185,6 +185,10 @@ int32_t CWelsPreProcess::BuildSpatialPicList (sWelsEncCtx* pCtx, const SSourcePi
     pSvcParam->SUsedPicRect.iTop  = 0;
     pSvcParam->SUsedPicRect.iWidth = ((kpSrcPic->iPicWidth >> 1) << 1);
     pSvcParam->SUsedPicRect.iHeight = ((kpSrcPic->iPicHeight >> 1) << 1);
+    if((pSvcParam->SUsedPicRect.iWidth<16)||((pSvcParam->SUsedPicRect.iHeight<16))){
+      WelsLog ( & (pCtx->sLogCtx), WELS_LOG_ERROR, "Don't support width(%d) or height(%d) which is less than 16 ",pSvcParam->SUsedPicRect.iWidth,pSvcParam->SUsedPicRect.iHeight);
+      return -1;
+    }
     if (WelsPreprocessReset (pCtx) != 0)
       return -1;
 
@@ -221,7 +225,7 @@ int32_t CWelsPreProcess::AnalyzeSpatialPic (sWelsEncCtx* pCtx, const int32_t kiD
   bool bCalculateVar = (pSvcParam->iRCMode >= RC_BITRATE_MODE && pCtx->eSliceType == I_SLICE);
 
   if (pSvcParam->iUsageType == SCREEN_CONTENT_REAL_TIME) {
-    SVAAFrameInfoExt* pVaaExt			= static_cast<SVAAFrameInfoExt*> (m_pEncCtx->pVaa);
+    SVAAFrameInfoExt* pVaaExt = static_cast<SVAAFrameInfoExt*> (m_pEncCtx->pVaa);
     SRefInfoParam* BestRefCandidateParam = (pCtx->bCurFrameMarkedAsSceneLtr) ? (& (pVaaExt->sVaaLtrBestRefCandidate[0])) :
                                            (& (pVaaExt->sVaaStrBestRefCandidate[0]));
     SPicture* pRefPic = m_pSpatialPic[0][BestRefCandidateParam->iSrcListIdx];
@@ -252,12 +256,11 @@ int32_t CWelsPreProcess::AnalyzeSpatialPic (sWelsEncCtx* pCtx, const int32_t kiD
 
       AdaptiveQuantCalculation (pCtx->pVaa, pCurPic, pRefPic);
     }
-    WelsExchangeSpatialPictures (&m_pLastSpatialPicture[kiDidx][1], &m_pLastSpatialPicture[kiDidx][0]);
   }
   return 0;
 }
 
-int32_t CWelsPreProcess::GetCurPicPosition(const int32_t kiDidx) {
+int32_t CWelsPreProcess::GetCurPicPosition (const int32_t kiDidx) {
   return (m_uiSpatialLayersInTemporal[kiDidx] - 1);
 }
 
@@ -265,7 +268,10 @@ int32_t CWelsPreProcess::UpdateSpatialPictures (sWelsEncCtx* pCtx, SWelsSvcCodin
     const int8_t iCurTid, const int32_t kiDidx) {
   if (pCtx->pSvcParam->iUsageType == SCREEN_CONTENT_REAL_TIME)
     return 0;
-  const int32_t kiCurPos = GetCurPicPosition(kiDidx);
+
+  WelsExchangeSpatialPictures (&m_pLastSpatialPicture[kiDidx][1], &m_pLastSpatialPicture[kiDidx][0]);
+
+  const int32_t kiCurPos = GetCurPicPosition (kiDidx);
   if (iCurTid < kiCurPos || pParam->iDecompStages == 0) {
     if ((iCurTid >= MAX_TEMPORAL_LEVEL) || (kiCurPos > MAX_TEMPORAL_LEVEL)) {
       InitLastSpatialPictures (pCtx);
@@ -278,15 +284,15 @@ int32_t CWelsPreProcess::UpdateSpatialPictures (sWelsEncCtx* pCtx, SWelsSvcCodin
       pCtx->bRefOfCurTidIsLtr[kiDidx][iCurTid] = false;
     }
     WelsExchangeSpatialPictures (&m_pSpatialPic[kiDidx][kiCurPos],
-                                   &m_pSpatialPic[kiDidx][iCurTid]);
+                                 &m_pSpatialPic[kiDidx][iCurTid]);
   }
   return 0;
 }
 
 
 /*
-*	SingleLayerPreprocess: down sampling if applicable
-*  @return:	exact number of spatial layers need to encoder indeed
+*   SingleLayerPreprocess: down sampling if applicable
+*  @return: exact number of spatial layers need to encoder indeed
 */
 int32_t CWelsPreProcess::SingleLayerPreprocess (sWelsEncCtx* pCtx, const SSourcePicture* kpSrc,
     Scaled_Picture* pScaledPicture) {
@@ -294,21 +300,21 @@ int32_t CWelsPreProcess::SingleLayerPreprocess (sWelsEncCtx* pCtx, const SSource
   int8_t  iDependencyId             = pSvcParam->iSpatialLayerNum - 1;
   int32_t iPicturePos               = m_uiSpatialLayersInTemporal[iDependencyId] - 1;
 
-  SPicture* pSrcPic					= NULL;	// large
-  SPicture* pDstPic					= NULL;	// small
-  SSpatialLayerConfig* pDlayerParam					= NULL;
-  SSpatialLayerInternal* pDlayerParamInternal					= NULL;
-  int32_t iSpatialNum					= 0;
-  int32_t iSrcWidth					= 0;
-  int32_t iSrcHeight					= 0;
-  int32_t iTargetWidth					= 0;
-  int32_t iTargetHeight					= 0;
+  SPicture* pSrcPic                 = NULL; // large
+  SPicture* pDstPic                 = NULL; // small
+  SSpatialLayerConfig* pDlayerParam = NULL;
+  SSpatialLayerInternal* pDlayerParamInternal = NULL;
+  int32_t iSpatialNum               = 0;
+  int32_t iSrcWidth                 = 0;
+  int32_t iSrcHeight                = 0;
+  int32_t iTargetWidth              = 0;
+  int32_t iTargetHeight             = 0;
   int32_t iTemporalId = 0;
-  int32_t iActualSpatialLayerNum      = 0;
+  int32_t iActualSpatialLayerNum    = 0;
 
   pDlayerParamInternal = &pSvcParam->sDependencyLayers[iDependencyId];
   pDlayerParam = &pSvcParam->sSpatialLayers[iDependencyId];
-  iTargetWidth	  = pDlayerParam->iVideoWidth;
+  iTargetWidth   = pDlayerParam->iVideoWidth;
   iTargetHeight  = pDlayerParam->iVideoHeight;
   iTemporalId    = pDlayerParamInternal->uiCodingIdx2TemporalId[pCtx->iCodingIndex & (pSvcParam->uiGopSize - 1)];
   iSrcWidth   = pSvcParam->SUsedPicRect.iWidth;
@@ -328,11 +334,12 @@ int32_t CWelsPreProcess::SingleLayerPreprocess (sWelsEncCtx* pCtx, const SSource
   pDstPic = pSrcPic;
   if (pScaledPicture->pScaledInputPicture) {
     // for highest downsampling
-    pDstPic		= m_pSpatialPic[iDependencyId][iPicturePos];
+    pDstPic = m_pSpatialPic[iDependencyId][iPicturePos];
     iShrinkWidth = pScaledPicture->iScaledWidth[iDependencyId];
     iShrinkHeight = pScaledPicture->iScaledHeight[iDependencyId];
   }
-  DownsamplePadding (pSrcPic, pDstPic, iSrcWidth, iSrcHeight, iShrinkWidth, iShrinkHeight, iTargetWidth, iTargetHeight, false);
+  DownsamplePadding (pSrcPic, pDstPic, iSrcWidth, iSrcHeight, iShrinkWidth, iShrinkHeight, iTargetWidth, iTargetHeight,
+                     false);
 
   if (pSvcParam->bEnableSceneChangeDetect && !pCtx->pVaa->bIdrPeriodFlag) {
     if (pSvcParam->iUsageType == SCREEN_CONTENT_REAL_TIME) {
@@ -363,38 +370,39 @@ int32_t CWelsPreProcess::SingleLayerPreprocess (sWelsEncCtx* pCtx, const SSource
     -- iActualSpatialLayerNum;
   }
 
-  m_pLastSpatialPicture[iDependencyId][1]	= m_pSpatialPic[iDependencyId][iPicturePos];
+  m_pLastSpatialPicture[iDependencyId][1] = m_pSpatialPic[iDependencyId][iPicturePos];
   -- iDependencyId;
 
   // generate other spacial layer
   // pSrc is
-  //	-- padded input pic, if downsample should be applied to generate highest layer, [if] block above
-  //	-- highest layer, if no downsampling, [else] block above
+  //    -- padded input pic, if downsample should be applied to generate highest layer, [if] block above
+  //    -- highest layer, if no downsampling, [else] block above
   if (pSvcParam->iSpatialLayerNum > 1) {
     while (iDependencyId >= 0) {
       pDlayerParamInternal = &pSvcParam->sDependencyLayers[iDependencyId];
       pDlayerParam = &pSvcParam->sSpatialLayers[iDependencyId];
-      iTargetWidth	= pDlayerParam->iVideoWidth;
-      iTargetHeight	= pDlayerParam->iVideoHeight;
+      iTargetWidth  = pDlayerParam->iVideoWidth;
+      iTargetHeight = pDlayerParam->iVideoHeight;
       iTemporalId = pDlayerParamInternal->uiCodingIdx2TemporalId[pCtx->iCodingIndex & (pSvcParam->uiGopSize - 1)];
-      iPicturePos		= m_uiSpatialLayersInTemporal[iDependencyId] - 1;
+      iPicturePos = m_uiSpatialLayersInTemporal[iDependencyId] - 1;
 
       // NOT work for CGS, FIXME
       // spatial layer is able to encode indeed
       if ((iTemporalId != INVALID_TEMPORAL_ID)) {
         // down sampling performed
 
-        pDstPic	= m_pSpatialPic[iDependencyId][iPicturePos];	// small
+        pDstPic = m_pSpatialPic[iDependencyId][iPicturePos]; // small
         iShrinkWidth = pScaledPicture->iScaledWidth[iDependencyId];
         iShrinkHeight = pScaledPicture->iScaledHeight[iDependencyId];
-        DownsamplePadding (pSrcPic, pDstPic, iSrcWidth, iSrcHeight, iShrinkWidth, iShrinkHeight, iTargetWidth, iTargetHeight, true);
+        DownsamplePadding (pSrcPic, pDstPic, iSrcWidth, iSrcHeight, iShrinkWidth, iShrinkHeight, iTargetWidth, iTargetHeight,
+                           true);
 
         WelsUpdateSpatialIdxMap (pCtx, iActualSpatialLayerNum - 1, pDstPic, iDependencyId);
 
         -- iActualSpatialLayerNum;
         ++ iSpatialNum;
 
-        m_pLastSpatialPicture[iDependencyId][1]	= m_pSpatialPic[iDependencyId][iPicturePos];
+        m_pLastSpatialPicture[iDependencyId][1] = m_pSpatialPic[iDependencyId][iPicturePos];
       }
       -- iDependencyId;
     }
@@ -405,13 +413,13 @@ int32_t CWelsPreProcess::SingleLayerPreprocess (sWelsEncCtx* pCtx, const SSource
 
 
 /*!
- * \brief	Whether input picture need be scaled?
+ * \brief   Whether input picture need be scaled?
  */
 bool JudgeNeedOfScaling (SWelsSvcCodingParam* pParam, Scaled_Picture* pScaledPicture) {
-  const int32_t kiInputPicWidth	= pParam->SUsedPicRect.iWidth;
+  const int32_t kiInputPicWidth  = pParam->SUsedPicRect.iWidth;
   const int32_t kiInputPicHeight = pParam->SUsedPicRect.iHeight;
-  const int32_t kiDstPicWidth		= pParam->sDependencyLayers[pParam->iSpatialLayerNum - 1].iActualWidth;
-  const int32_t kiDstPicHeight	= pParam->sDependencyLayers[pParam->iSpatialLayerNum - 1].iActualHeight;
+  const int32_t kiDstPicWidth    = pParam->sDependencyLayers[pParam->iSpatialLayerNum - 1].iActualWidth;
+  const int32_t kiDstPicHeight   = pParam->sDependencyLayers[pParam->iSpatialLayerNum - 1].iActualHeight;
   bool bNeedDownsampling = true;
 
   int32_t iSpatialIdx = pParam->iSpatialLayerNum - 1;
@@ -423,17 +431,17 @@ bool JudgeNeedOfScaling (SWelsSvcCodingParam* pParam, Scaled_Picture* pScaledPic
 
   for (; iSpatialIdx >= 0; iSpatialIdx --) {
     SSpatialLayerInternal* pCurLayer = &pParam->sDependencyLayers[iSpatialIdx];
-    int32_t iCurDstWidth			= pCurLayer->iActualWidth;
-    int32_t iCurDstHeight			= pCurLayer->iActualHeight;
-    int32_t iInputWidthXDstHeight	= kiInputPicWidth * iCurDstHeight;
-    int32_t iInputHeightXDstWidth	= kiInputPicHeight * iCurDstWidth;
+    int32_t iCurDstWidth             = pCurLayer->iActualWidth;
+    int32_t iCurDstHeight            = pCurLayer->iActualHeight;
+    int32_t iInputWidthXDstHeight    = kiInputPicWidth * iCurDstHeight;
+    int32_t iInputHeightXDstWidth    = kiInputPicHeight * iCurDstWidth;
 
     if (iInputWidthXDstHeight > iInputHeightXDstWidth) {
-      pScaledPicture->iScaledWidth[iSpatialIdx] = iCurDstWidth;
+      pScaledPicture->iScaledWidth[iSpatialIdx] = WELS_MAX (iCurDstWidth, 4);
       pScaledPicture->iScaledHeight[iSpatialIdx] = WELS_MAX (iInputHeightXDstWidth / kiInputPicWidth, 4);
     } else {
       pScaledPicture->iScaledWidth[iSpatialIdx] = WELS_MAX (iInputWidthXDstHeight / kiInputPicHeight, 4);
-      pScaledPicture->iScaledHeight[iSpatialIdx] = iCurDstHeight;
+      pScaledPicture->iScaledHeight[iSpatialIdx] = WELS_MAX (iCurDstHeight, 4);
     }
   }
 
@@ -459,21 +467,21 @@ void  FreeScaledPic (Scaled_Picture*  pScaledPicture, CMemoryAlign* pMemoryAlign
 }
 
 int32_t CWelsPreProcess::InitLastSpatialPictures (sWelsEncCtx* pCtx) {
-  SWelsSvcCodingParam* pParam	= pCtx->pSvcParam;
-  const int32_t kiDlayerCount			= pParam->iSpatialLayerNum;
-  int32_t iDlayerIndex					= 0;
+  SWelsSvcCodingParam* pParam   = pCtx->pSvcParam;
+  const int32_t kiDlayerCount   = pParam->iSpatialLayerNum;
+  int32_t iDlayerIndex          = 0;
   if (pParam->iUsageType == SCREEN_CONTENT_REAL_TIME) {
     for (; iDlayerIndex < MAX_DEPENDENCY_LAYER; iDlayerIndex++) {
-      m_pLastSpatialPicture[iDlayerIndex][0]	= m_pLastSpatialPicture[iDlayerIndex][1] = NULL;
+      m_pLastSpatialPicture[iDlayerIndex][0] = m_pLastSpatialPicture[iDlayerIndex][1] = NULL;
     }
   } else {
     for (; iDlayerIndex < kiDlayerCount; iDlayerIndex++) {
       const int32_t kiLayerInTemporal = m_uiSpatialLayersInTemporal[iDlayerIndex];
-      m_pLastSpatialPicture[iDlayerIndex][0]	= m_pSpatialPic[iDlayerIndex][kiLayerInTemporal - 2];
-      m_pLastSpatialPicture[iDlayerIndex][1]	= NULL;
+      m_pLastSpatialPicture[iDlayerIndex][0] = m_pSpatialPic[iDlayerIndex][kiLayerInTemporal - 2];
+      m_pLastSpatialPicture[iDlayerIndex][1] = NULL;
     }
     for (; iDlayerIndex < MAX_DEPENDENCY_LAYER; iDlayerIndex++) {
-      m_pLastSpatialPicture[iDlayerIndex][0]	= m_pLastSpatialPicture[iDlayerIndex][1] = NULL;
+      m_pLastSpatialPicture[iDlayerIndex][0] = m_pLastSpatialPicture[iDlayerIndex][1] = NULL;
     }
   }
   return 0;
@@ -575,14 +583,14 @@ int32_t CWelsPreProcess::DownsamplePadding (SPicture* pSrc, SPicture* pDstPic,
                         iSrcWidth, iSrcHeight);
     }
   } else {
-    memcpy (&sDstPicMap, &sSrcPixMap, sizeof (sDstPicMap));	// confirmed_safe_unsafe_usage
+    memcpy (&sDstPicMap, &sSrcPixMap, sizeof (sDstPicMap)); // confirmed_safe_unsafe_usage
   }
 
   // get rid of odd line
   iShrinkWidth -= (iShrinkWidth & 1);
   iShrinkHeight -= (iShrinkHeight & 1);
   Padding ((uint8_t*)sDstPicMap.pPixel[0], (uint8_t*)sDstPicMap.pPixel[1], (uint8_t*)sDstPicMap.pPixel[2],
-           sDstPicMap.iStride[0], sDstPicMap.iStride[1],	iShrinkWidth, iTargetWidth, iShrinkHeight, iTargetHeight);
+           sDstPicMap.iStride[0], sDstPicMap.iStride[1], iShrinkWidth, iTargetWidth, iShrinkHeight, iTargetHeight);
 
   return iRet;
 }
@@ -614,9 +622,9 @@ void CWelsPreProcess::VaaCalculation (SVAAFrameInfo* pVaaInfo, SPicture* pCurPic
     sRefPixMap.iStride[0] = pRefPicture->iLineSize[0];
     sRefPixMap.eFormat = VIDEO_FORMAT_I420;
 
-    calc_param.iCalcVar	= bCalculateVar;
-    calc_param.iCalcBgd	= bCalculateBGD;
-    calc_param.iCalcSsd	= bCalculateSQDiff;
+    calc_param.iCalcVar = bCalculateVar;
+    calc_param.iCalcBgd = bCalculateBGD;
+    calc_param.iCalcSsd = bCalculateSQDiff;
     calc_param.pCalcResult = &pVaaInfo->sVaaCalcInfo;
 
     m_pInterfaceVp->Set (iMethodIdx, &calc_param);
@@ -630,14 +638,14 @@ void CWelsPreProcess::BackgroundDetection (SVAAFrameInfo* pVaaInfo, SPicture* pC
     pVaaInfo->iPicWidth     = pCurPicture->iWidthInPixel;
     pVaaInfo->iPicHeight    = pCurPicture->iHeightInPixel;
 
-    pVaaInfo->iPicStride	= pCurPicture->iLineSize[0];
-    pVaaInfo->iPicStrideUV	= pCurPicture->iLineSize[1];
-    pVaaInfo->pCurY			= pCurPicture->pData[0];
-    pVaaInfo->pRefY			= pRefPicture->pData[0];
-    pVaaInfo->pCurU			= pCurPicture->pData[1];
-    pVaaInfo->pRefU			= pRefPicture->pData[1];
-    pVaaInfo->pCurV			= pCurPicture->pData[2];
-    pVaaInfo->pRefV			= pRefPicture->pData[2];
+    pVaaInfo->iPicStride    = pCurPicture->iLineSize[0];
+    pVaaInfo->iPicStrideUV  = pCurPicture->iLineSize[1];
+    pVaaInfo->pCurY         = pCurPicture->pData[0];
+    pVaaInfo->pRefY         = pRefPicture->pData[0];
+    pVaaInfo->pCurU         = pCurPicture->pData[1];
+    pVaaInfo->pRefU         = pRefPicture->pData[1];
+    pVaaInfo->pCurV         = pCurPicture->pData[2];
+    pVaaInfo->pRefV         = pRefPicture->pData[2];
 
     int32_t iMethodIdx = METHOD_BACKGROUND_DETECTION;
     SPixMap sSrcPixMap;
@@ -673,8 +681,8 @@ void CWelsPreProcess::BackgroundDetection (SVAAFrameInfo* pVaaInfo, SPicture* pC
     m_pInterfaceVp->Set (iMethodIdx, (void*)&BGDParam);
     m_pInterfaceVp->Process (iMethodIdx, &sSrcPixMap, &sRefPixMap);
   } else {
-    int32_t	iPicWidthInMb	= (pCurPicture->iWidthInPixel + 15) >> 4;
-    int32_t	iPicHeightInMb = (pCurPicture->iHeightInPixel + 15) >> 4;
+    int32_t iPicWidthInMb  = (pCurPicture->iWidthInPixel  + 15) >> 4;
+    int32_t iPicHeightInMb = (pCurPicture->iHeightInPixel + 15) >> 4;
     memset (pVaaInfo->pVaaBackgroundMbFlag, 0, iPicWidthInMb * iPicHeightInMb);
   }
 }
@@ -713,11 +721,11 @@ void CWelsPreProcess::AdaptiveQuantCalculation (SVAAFrameInfo* pVaaInfo, SPictur
 }
 
 void CWelsPreProcess::SetRefMbType (sWelsEncCtx* pCtx, uint32_t** pRefMbTypeArray, int32_t iRefPicType) {
-  const uint8_t uiTid	    = pCtx->uiTemporalId;
+  const uint8_t uiTid       = pCtx->uiTemporalId;
   const uint8_t uiDid       = pCtx->uiDependencyId;
   SRefList* pRefPicLlist    = pCtx->ppRefPicListExt[uiDid];
-  SLTRState* pLtr	    = &pCtx->pLtr[uiDid];
-  uint8_t i							= 0;
+  SLTRState* pLtr           = &pCtx->pLtr[uiDid];
+  uint8_t i = 0;
 
   if (pCtx->pSvcParam->bEnableLongTermReference && pLtr->bReceivedT0LostFlag && uiTid == 0) {
     for (i = 0; i < pRefPicLlist->uiLongRefCount; i++) {
@@ -745,8 +753,8 @@ void CWelsPreProcess::AnalyzePictureComplexity (sWelsEncCtx* pCtx, SPicture* pCu
   int32_t iComplexityAnalysisMode = 0;
 
   if (pSvcParam->iUsageType == SCREEN_CONTENT_REAL_TIME) {
-    SVAAFrameInfoExt* pVaaExt		= static_cast<SVAAFrameInfoExt*> (pCtx->pVaa);
-    SComplexityAnalysisScreenParam* sComplexityAnalysisParam	= &pVaaExt->sComplexityScreenParam;
+    SVAAFrameInfoExt* pVaaExt = static_cast<SVAAFrameInfoExt*> (pCtx->pVaa);
+    SComplexityAnalysisScreenParam* sComplexityAnalysisParam = &pVaaExt->sComplexityScreenParam;
     SWelsSvcRc* pWelsSvcRc = &pCtx->pWelsSvcRc[kiDependencyId];
 
     if (pCtx->eSliceType == P_SLICE)
@@ -797,7 +805,7 @@ void CWelsPreProcess::AnalyzePictureComplexity (sWelsEncCtx* pCtx, SPicture* pCu
       m_pInterfaceVp->Get (iMethodIdx, (void*)sComplexityAnalysisParam);
 
   } else {
-    SVAAFrameInfo* pVaaInfo	 = pCtx->pVaa;
+    SVAAFrameInfo* pVaaInfo = pCtx->pVaa;
     SComplexityAnalysisParam* sComplexityAnalysisParam = & (pVaaInfo->sComplexityAnalysisParam);
     SWelsSvcRc* SWelsSvcRc = &pCtx->pWelsSvcRc[kiDependencyId];
 
@@ -990,7 +998,7 @@ void CWelsPreProcess::SaveBestRefToVaa (SRefInfoParam& sRefSaved, SRefInfoParam*
 ESceneChangeIdc CWelsPreProcess::DetectSceneChangeScreen (sWelsEncCtx* pCtx, SPicture* pCurPicture) {
 #define STATIC_SCENE_MOTION_RATIO 0.01f
   SWelsSvcCodingParam* pSvcParam = pCtx->pSvcParam;
-  SVAAFrameInfoExt* pVaaExt			= static_cast<SVAAFrameInfoExt*> (pCtx->pVaa);
+  SVAAFrameInfoExt* pVaaExt = static_cast<SVAAFrameInfoExt*> (pCtx->pVaa);
   if (NULL == pCtx || NULL == pVaaExt || NULL == pCurPicture) {
     return LARGE_CHANGED_SCENE;
   }
@@ -1033,7 +1041,10 @@ ESceneChangeIdc CWelsPreProcess::DetectSceneChangeScreen (sWelsEncCtx* pCtx, SPi
                                           (pCurPicture->iHeightInPixel >> 3) * STATIC_SCENE_MOTION_RATIO));
   const uint8_t iCurTid = GetTemporalLevel (&pSvcParam->sDependencyLayers[m_pEncCtx->sSpatialIndexMap[0].iDid],
                           m_pEncCtx->iCodingIndex, pSvcParam->uiGopSize);
-  const int32_t iClosestLtrFrameNum = pCtx->pLtr[iTargetDid].iLastLtrIdx[iCurTid];//TBD
+  if (iCurTid == INVALID_TEMPORAL_ID) {
+    return LARGE_CHANGED_SCENE;
+  }
+  const int32_t iClosestLtrFrameNum = pCtx->pLtr[iTargetDid].iLastLtrIdx[iCurTid];
   if (pSvcParam->bEnableLongTermReference) {
     GetAvailableRefListLosslessScreenRefSelection (pSrcPicList, iCurTid, iClosestLtrFrameNum, &sAvailableRefList[0],
         iAvailableRefNum,
@@ -1140,7 +1151,7 @@ ESceneChangeIdc CWelsPreProcess::DetectSceneChangeScreen (sWelsEncCtx* pCtx, SPi
 
 int32_t CWelsPreProcess::GetRefFrameInfo (int32_t iRefIdx, bool bCurrentFrameIsSceneLtr, SPicture*& pRefOri) {
   const int32_t iTargetDid = m_pEncCtx->pSvcParam->iSpatialLayerNum - 1;
-  SVAAFrameInfoExt* pVaaExt			= static_cast<SVAAFrameInfoExt*> (m_pEncCtx->pVaa);
+  SVAAFrameInfoExt* pVaaExt = static_cast<SVAAFrameInfoExt*> (m_pEncCtx->pVaa);
   SRefInfoParam* pBestRefCandidateParam = (bCurrentFrameIsSceneLtr) ? (& (pVaaExt->sVaaLtrBestRefCandidate[iRefIdx])) :
                                           (& (pVaaExt->sVaaStrBestRefCandidate[iRefIdx]));
   pRefOri = m_pSpatialPic[iTargetDid][pBestRefCandidateParam->iSrcListIdx];
@@ -1195,13 +1206,13 @@ int32_t CWelsPreProcess::UpdateBlockIdcForScreen (uint8_t*  pCurBlockStaticPoint
 }
 
 /*!
-* \brief	exchange two picture pData planes
-* \param	ppPic1		picture pointer to picture 1
-* \param	ppPic2		picture pointer to picture 2
-* \return	none
+* \brief    exchange two picture pData planes
+* \param    ppPic1      picture pointer to picture 1
+* \param    ppPic2      picture pointer to picture 2
+* \return   none
 */
 void CWelsPreProcess::WelsExchangeSpatialPictures (SPicture** ppPic1, SPicture** ppPic2) {
-  SPicture* tmp	= *ppPic1;
+  SPicture* tmp = *ppPic1;
 
   assert (*ppPic1 != *ppPic2);
 
@@ -1209,7 +1220,7 @@ void CWelsPreProcess::WelsExchangeSpatialPictures (SPicture** ppPic1, SPicture**
   *ppPic2 = tmp;
 }
 
-void CWelsPreProcess::UpdateSrcListLosslessScreenRefSelectionWithLtr (SPicture*	pCurPicture, const int32_t kiCurDid,
+void CWelsPreProcess::UpdateSrcListLosslessScreenRefSelectionWithLtr (SPicture* pCurPicture, const int32_t kiCurDid,
     const int32_t kuiMarkLongTermPicIdx, SPicture** pLongRefList) {
   SPicture** pLongRefSrcList = &m_pSpatialPic[kiCurDid][0];
   for (int32_t i = 0; i < MAX_REF_PIC_COUNT; ++i) {
@@ -1225,14 +1236,14 @@ void CWelsPreProcess::UpdateSrcListLosslessScreenRefSelectionWithLtr (SPicture*
   m_iAvaliableRefInSpatialPicList = MAX_REF_PIC_COUNT;
   (GetCurrentFrameFromOrigList (kiCurDid))->SetUnref();
 }
-void CWelsPreProcess::UpdateSrcList (SPicture*	pCurPicture, const int32_t kiCurDid, SPicture** pShortRefList,
+void CWelsPreProcess::UpdateSrcList (SPicture* pCurPicture, const int32_t kiCurDid, SPicture** pShortRefList,
                                      const uint32_t kuiShortRefCount) {
   SPicture** pRefSrcList = &m_pSpatialPic[kiCurDid][0];
 
   //pRefSrcList[0] is for current frame
   if (pCurPicture->bUsedAsRef || pCurPicture->bIsLongRef) {
     if (pCurPicture->iPictureType == P_SLICE && pCurPicture->uiTemporalId != 0) {
-      for (int iRefIdx = kuiShortRefCount - 1; iRefIdx >= 0; --iRefIdx)	{
+      for (int iRefIdx = kuiShortRefCount - 1; iRefIdx >= 0; --iRefIdx) {
         WelsExchangeSpatialPictures (&pRefSrcList[iRefIdx + 1],
                                      &pRefSrcList[iRefIdx]);
       }
@@ -1292,12 +1303,12 @@ void  CWelsPreProcess::WelsMoveMemoryWrapper (SWelsSvcCodingParam* pSvcParam, SP
   int32_t  iSrcWidth       = kpSrc->iPicWidth;
   int32_t  iSrcHeight      = kpSrc->iPicHeight;
 
-  if (iSrcHeight > kiTargetHeight) 	iSrcHeight = kiTargetHeight;
-  if (iSrcWidth > kiTargetWidth)		iSrcWidth  = kiTargetWidth;
+  if (iSrcHeight > kiTargetHeight) iSrcHeight = kiTargetHeight;
+  if (iSrcWidth > kiTargetWidth)   iSrcWidth  = kiTargetWidth;
 
   // copy from fr26 to fix the odd uiSize failed issue
-  if (iSrcWidth & 0x1)		-- iSrcWidth;
-  if (iSrcHeight & 0x1)		-- iSrcHeight;
+  if (iSrcWidth & 0x1)  -- iSrcWidth;
+  if (iSrcHeight & 0x1) -- iSrcHeight;
 
   const int32_t kiSrcTopOffsetY = pSvcParam->SUsedPicRect.iTop;
   const int32_t kiSrcTopOffsetUV = (kiSrcTopOffsetY >> 1);
